#Test if disassembler correctly prints DSP instructions.
	vmac2hnfr	r0,r2,r4
	abssh		r0,r2
	aslacc		r0
	aslsacc		r0
	asrsr		r0,r2,r4
	cbflyhf0r	r0,r2,r4
	cbflyhf1r	r0,r2
	cmacchfr	r0,r2,r4
	cmacchnfr	r0,r2,r4
	cmachfr		r0,r2,r4
	cmachnfr	r0,r2,r4
	cmpychfr	r0,r2,r4
	cmpychnfr	r0,r2,r4
	cmpyhfmr	r0,r2,r4
	cmpyhfr		r0,r2,r4
	cmpyhnfr	r0,r2,r4
	divacc		r0
	dmachbl		r0,r2,r4
	dmachbm		r0,r2,r4
	dmachf		r0,r2,r4
	dmachfr		r0,r2,r4
	dmpyhbl		r0,r2,r4
	dmpyhbm		r0,r2,r4
	dmpyhf		r0,r2,r4
	dmpyhfr		r0,r2,r4
	dmpyhwf		r0,r2,r4
	flagacc		r0
	getacc		r0,r2
	macf		r0,r2,r4
	macfr		r0,r2,r4
	macwhfm		r0,r2,r4
	macwhfmr	r0,r2,r4
	macwhl		r0,r2,r4
	macwhul		r0,r2,r4
	mpyf		r0,r2,r4
	mpyfr		r0,r2,r4
	mpywhfl		r0,r2,r4
	mpywhflr	r0,r2,r4
	mpywhfm		r0,r2,r4
	mpywhfmr	r0,r2,r4
	mpywhl		r0,r2,r4
	mpywhul		r0,r2,r4
	msubdf		r0,r2,r4
	msubf		r0,r2,r4
	msubfr		r0,r2,r4
	negsh		r0,r2
	normacc		r0,r2
	rndh		r0,r2
	sath		r0,r2
	setacc		r0,r2,r4
	sqrtacc		r0
	vabs2h		r0,r2
	vabss2h		r0,r2
	vadd4b		r0,r2,r4
	vadds2h		r0,r2,r4
	vaddsubs2h	r0,r2,r4
	valgn2h		r0,r2,r4
	vasl2h		r0,r2,r4
	vasls2h		r0,r2,r4
	vasr2h		r0,r2,r4
	vasrs2h		r0,r2,r4
	vasrsr2h	r0,r2,r4
	vext2bhl	r0,r2
	vext2bhm	r0,r2
	vlsr2h		r0,r2,r4
	vmac2h		r0,r2,r4
	vmac2hf		r0,r2,r4
	vmac2hfr	r0,r2,r4
	vmac2hu		r0,r2,r4
	vmax2h		r0,r2,r4
	vmin2h		r0,r2,r4
	vmpy2h		r0,r2,r4
	vmpy2hf		r0,r2,r4
	vmpy2hfr	r0,r2,r4
	vmpy2hu		r0,r2,r4
	vmpy2hwf	r0,r2,r4
	vmsub2hf	r0,r2,r4
	vmsub2hfr	r0,r2,r4
	vmsub2hnfr	r0,r2,r4
	vneg2h		r0,r2
	vnegs2h		r0,r2
	vnorm2h		r0,r2
	vrep2hl		r0,r2
	vrep2hm		r0,r2
	vsext2bhl	r0,r2
	vsext2bhm	r0,r2
	vsub4b		r0,r2,r4
	vsubadds2h	r0,r2,r4
	vsubs2h		r0,r2,r4
