	.text

	movi	a2, fh@plt
	movi	a2, fp@plt
	movi	a2, fi@plt

	movi	a2, fh
	movi	a2, fp
	movi	a2, fi

	.section ".text.a"

	movi	a2, fh@plt
	movi	a2, fp@plt
	movi	a2, fi@plt

	movi	a2, fh
	movi	a2, fp
	movi	a2, fi
