#source: relax-undef-weak.s
#ld: -shared
#readelf: -r
#...
Relocation section '\.rela\.dyn' .* 3 .*
#...
.*R_XTENSA_RTLD.*
.*R_XTENSA_RTLD.*
.*R_XTENSA_GLOB_DAT.*fd.*
#...
Relocation section '\.rela\.plt' .* 1 .*
#...
.*R_XTENSA_JMP_SLOT.*fd.*
#...
