.*: Assembler messages:
.*:8: Warning: wrong size instruction in a 16-bit branch delay slot
.*:10: Warning: wrong size instruction in a 16-bit branch delay slot
.*:12: Warning: wrong size instruction in a 16-bit branch delay slot
.*:14: Warning: wrong size instruction in a 16-bit branch delay slot
.*:16: Warning: wrong size instruction in a 16-bit branch delay slot
.*:18: Warning: wrong size instruction in a 16-bit branch delay slot
.*:20: Warning: wrong size instruction in a 16-bit branch delay slot
