.*: Assembler messages:
.*:2: Error: unsupported syntax for `lcall'
.*:3: Error: unsupported syntax for `lfs'
.*:4: Error: unsupported syntax for `lfs'
.*:5: Error: unsupported syntax for `lgs'
.*:6: Error: unsupported syntax for `lgs'
.*:7: Error: unsupported syntax for `ljmp'
.*:8: Error: unsupported syntax for `lss'
.*:9: Error: unsupported syntax for `lss'
.*:12: Error: unsupported syntax for `call'
.*:13: Error: unsupported syntax for `lfs'
.*:14: Error: unsupported syntax for `lfs'
.*:15: Error: unsupported syntax for `lgs'
.*:16: Error: unsupported syntax for `lgs'
.*:17: Error: unsupported syntax for `jmp'
.*:18: Error: unsupported syntax for `lss'
.*:19: Error: unsupported syntax for `lss'
GAS LISTING .*
#pass
