# Test wrpr
	.text
	wrpr %g1,%g2,%tpc
	wrpr %g1,%tpc
	wrpr %g1,666,%tpc
	wrpr 666,%g1,%tpc
	wrpr 666,%tpc
	wrpr %g1,%g2,%tnpc
	wrpr %g1,%tnpc
	wrpr %g1,666,%tnpc
	wrpr 666,%g1,%tnpc
	wrpr 666,%tnpc
	wrpr %g1,%g2,%tstate
	wrpr %g1,%tstate
	wrpr %g1,666,%tstate
	wrpr 666,%g1,%tstate
	wrpr 666,%tstate
	wrpr %g1,%g2,%tt
	wrpr %g1,%tt
	wrpr %g1,666,%tt
	wrpr 666,%g1,%tt
	wrpr 666,%tt
	wrpr %g1,%g2,%tick
	wrpr %g1,%tick
	wrpr %g1,666,%tick
	wrpr 666,%g1,%tick
	wrpr 666,%tick
	wrpr %g1,%g2,%tba
	wrpr %g1,%tba
	wrpr %g1,666,%tba
	wrpr 666,%g1,%tba
	wrpr 666,%tba
	wrpr %g1,%g2,%pstate
	wrpr %g1,%pstate
	wrpr %g1,666,%pstate
	wrpr 666,%g1,%pstate
	wrpr 666,%pstate
	wrpr %g1,%g2,%tl
	wrpr %g1,%tl
	wrpr %g1,666,%tl
	wrpr 666,%g1,%tl
	wrpr 666,%tl
	wrpr %g1,%g2,%pil
	wrpr %g1,%pil
	wrpr %g1,666,%pil
	wrpr 666,%g1,%pil
	wrpr 666,%pil
	wrpr %g1,%g2,%cwp
	wrpr %g1,%cwp
	wrpr %g1,666,%cwp
	wrpr 666,%g1,%cwp
	wrpr 666,%cwp
	wrpr %g1,%g2,%cansave
	wrpr %g1,%cansave
	wrpr %g1,666,%cansave
	wrpr 666,%g1,%cansave
	wrpr 666,%cansave
	wrpr %g1,%g2,%canrestore
	wrpr %g1,%canrestore
	wrpr %g1,666,%canrestore
	wrpr 666,%g1,%canrestore
	wrpr 666,%canrestore
	wrpr %g1,%g2,%cleanwin
	wrpr %g1,%cleanwin
	wrpr %g1,666,%cleanwin
	wrpr 666,%g1,%cleanwin
	wrpr 666,%cleanwin
	wrpr %g1,%g2,%otherwin
	wrpr %g1,%otherwin
	wrpr %g1,666,%otherwin
	wrpr 666,%g1,%otherwin
	wrpr 666,%otherwin
	wrpr %g1,%g2,%wstate
	wrpr %g1,%wstate
	wrpr %g1,666,%wstate
	wrpr 666,%g1,%wstate
	wrpr 666,%wstate
	wrpr %g1,%g2,%fq
	wrpr %g1,%fq
	wrpr %g1,666,%fq
	wrpr 666,%g1,%fq
	wrpr 666,%fq
	wrpr %g1,%g2,%gl
	wrpr %g1,%gl
	wrpr %g1,666,%gl
	wrpr 666,%g1,%gl
	wrpr 666,%gl
	wrpr %g1,%g2,%pmcdper
	wrpr %g1,%pmcdper
	wrpr %g1,666,%pmcdper
	wrpr 666,%g1,%pmcdper
	wrpr 666,%pmcdper
	wrpr %g1,%g2,%ver
	wrpr %g1,%ver
	wrpr %g1,666,%ver
	wrpr 666,%g1,%ver
	wrpr 666,%ver
