Primary GOT:
 Canonical gp value: 00028030

 Reserved entries:
   Address     Access  Initial Purpose
  00020040 -32752\(gp\) 00000000 Lazy resolver
  00020044 -32748\(gp\) 80000000 Module pointer \(GNU extension\)

 Local entries:
   Address     Access  Initial
  00020048 -32744\(gp\) 00020000
